_, BrokerGarbage_LootManager = ...

local function ShowTooltip(self)
	GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
	if self.tiptext then
		GameTooltip:SetText(self.tiptext, nil, nil, nil, nil, true)
	elseif self.itemLink then
		GameTooltip:SetHyperlink(self.itemLink)
	end
	GameTooltip:Show()
end
local function HideTooltip() GameTooltip:Hide() end

local function CreateHorizontalRule(parent)
	local line = parent:CreateTexture(nil, "ARTWORK")
	line:SetHeight(8)
	line:SetTexture("Interface\\Tooltips\\UI-Tooltip-Border")
	line:SetTexCoord(0.81, 0.94, 0.5, 1)
	
	return line
end

local function Options_LootManager(pluginID)
	local function Toggle(self)
		if not (self and self.stat) then return end

		local variable
		if self.global then
			if BGLM_GlobalDB[self.stat] ~= nil then
				BGLM_GlobalDB[self.stat] = not BGLM_GlobalDB[self.stat]
			end
		else
			variable = BGLM_LocalDB[self.stat]
			
			if BGLM_LocalDB[self.stat] ~= nil then
				BGLM_LocalDB[self.stat] = not BGLM_LocalDB[self.stat]
			end
		end
	end
	
	local panel, tab = BrokerGarbage:CreateOptionsTab(pluginID)
	
	local subtitle = panel:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subtitle:SetPoint("TOPLEFT", 16, -16)
	subtitle:SetPoint("RIGHT", panel, -16, 0)
	subtitle:SetHeight(50)
	subtitle:SetNonSpaceWrap(true)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText(BrokerGarbage_LootManager.locale.LMSubTitle)
	
	local looting = LibStub("tekKonfig-Group").new(panel, BrokerGarbage_LootManager.locale.GroupLooting, "TOPLEFT", subtitle, "BOTTOMLEFT", 0, -6)--panel, 21, -16)
	looting:SetHeight(150); looting:SetWidth(180)
	looting:SetBackdropColor(0.1, 0.1, 0.1, 0.4)

	local autoLoot = LibStub("tekKonfig-Checkbox").new(looting, nil, BrokerGarbage_LootManager.locale.LMAutoLootTitle, "TOPLEFT", 4, -2)
	autoLoot.tiptext = BrokerGarbage_LootManager.locale.LMAutoLootTooltip .. BrokerGarbage.locale.GlobalSetting
	autoLoot.stat = "autoLoot"
	autoLoot.global = true
	autoLoot:SetChecked(BGLM_GlobalDB.autoLoot)
	autoLoot:SetScript("OnClick", Toggle)

	local iconSize = 26
	local skinning = CreateFrame("CheckButton", nil, looting)
	skinning:SetPoint("TOPLEFT", autoLoot, "BOTTOMRIGHT", 14, 2)
	skinning:SetWidth(iconSize); skinning:SetHeight(iconSize)
	skinning:SetChecked(BGLM_GlobalDB.autoLootSkinning)
	skinning.tiptext = BrokerGarbage_LootManager.locale.LMAutoLootSkinningTooltip .. BrokerGarbage.locale.GlobalSetting
	skinning.stat = "autoLootSkinning"
	skinning.global = true
	skinning:SetNormalTexture("Interface\\Icons\\inv_misc_pelt_wolf_01")
	skinning:SetPushedTexture("Interface\\Buttons\\UI-Quickslot-Depress")
	skinning:SetHighlightTexture("Interface\\Buttons\\ButtonHilight-Square")
	skinning:SetCheckedTexture("Interface\\Buttons\\CheckButtonHilight")
	skinning:SetScript("OnClick", Toggle)
	skinning:SetScript("OnEnter", ShowTooltip)
	skinning:SetScript("OnLeave", HideTooltip)

	local fishing = CreateFrame("CheckButton", nil, looting)
	fishing:SetPoint("TOPLEFT", skinning, "TOPRIGHT", 2, 0)
	fishing:SetWidth(iconSize); fishing:SetHeight(iconSize)
	fishing:SetChecked(BGLM_GlobalDB.autoLootFishing)
	fishing.tiptext = BrokerGarbage_LootManager.locale.LMAutoLootFishingTooltip .. BrokerGarbage.locale.GlobalSetting
	fishing.stat = "autoLootFishing"
	fishing.global = true
	fishing:SetNormalTexture("Interface\\Icons\\Trade_Fishing")
	fishing:SetPushedTexture("Interface\\Buttons\\UI-Quickslot-Depress")
	fishing:SetHighlightTexture("Interface\\Buttons\\ButtonHilight-Square")
	fishing:SetCheckedTexture("Interface\\Buttons\\CheckButtonHilight")
	-- "Interface\\Icons\\Trade_Fishing" / "Interface\\Icons\\INV_Fishingpole_02"
	fishing:SetScript("OnClick", Toggle)
	fishing:SetScript("OnEnter", ShowTooltip)
	fishing:SetScript("OnLeave", HideTooltip)
	
	local stealing = CreateFrame("CheckButton", nil, looting)
	stealing:SetPoint("TOPLEFT", fishing, "TOPRIGHT", 2, 0)
	stealing:SetWidth(iconSize); stealing:SetHeight(iconSize)
	stealing:SetChecked(BGLM_GlobalDB.autoLootPickpocket)
	stealing.tiptext = BrokerGarbage_LootManager.locale.LMAutoLootPickpocketTooltip .. BrokerGarbage.locale.GlobalSetting
	stealing.stat = "autoLootPickpocket"
	stealing.global = true
	stealing:SetNormalTexture("Interface\\Icons\\INV_Misc_Bag_11")
	stealing:SetPushedTexture("Interface\\Buttons\\UI-Quickslot-Depress")
	stealing:SetHighlightTexture("Interface\\Buttons\\ButtonHilight-Square")
	stealing:SetCheckedTexture("Interface\\Buttons\\CheckButtonHilight")
	stealing:SetScript("OnClick", Toggle)
	stealing:SetScript("OnEnter", ShowTooltip)
	stealing:SetScript("OnLeave", HideTooltip)
	
	-- -----------------------------------------------------------------
	local line = CreateHorizontalRule(looting)
	line:SetPoint("TOPLEFT", autoLoot, "BOTTOMLEFT", 2, -24)
	line:SetPoint("RIGHT", -6, 2)
	-- -----------------------------------------------------------------
	
	local inCombat = LibStub("tekKonfig-Checkbox").new(looting, nil, BrokerGarbage_LootManager.locale.LMEnableInCombatTitle, "TOPLEFT", autoLoot, "BOTTOMLEFT", 0, -30)
	inCombat.tiptext = BrokerGarbage_LootManager.locale.LMEnableInCombatTooltip .. BrokerGarbage.locale.GlobalSetting
	inCombat.stat = "useInCombat"
	inCombat.global = true
	inCombat:SetChecked(BGLM_GlobalDB.useInCombat)
	inCombat:SetScript("OnClick", Toggle)
	
	local closeLoot = LibStub("tekKonfig-Checkbox").new(looting, nil, BrokerGarbage_LootManager.locale.LMCloseLootTitle, "TOPLEFT", inCombat, "BOTTOMLEFT", 0, 4)
	closeLoot.tiptext = BrokerGarbage_LootManager.locale.LMCloseLootTooltip .. BrokerGarbage.locale.GlobalSetting
	closeLoot.stat = "closeLootWindow"
	closeLoot.global = true
	closeLoot:SetChecked(BGLM_GlobalDB.closeLootWindow)
	closeLoot:SetScript("OnClick", Toggle)
	
	local forceClear = LibStub("tekKonfig-Checkbox").new(looting, nil, BrokerGarbage_LootManager.locale.LMForceClearTitle, "TOPLEFT", closeLoot, "BOTTOMLEFT", 0, 4)
	forceClear.tiptext = BrokerGarbage_LootManager.locale.LMForceClearTooltip .. BrokerGarbage.locale.GlobalSetting
	forceClear.stat = "forceClear"
	forceClear.global = true
	forceClear:SetChecked(BGLM_GlobalDB.forceClear)
	forceClear:SetScript("OnClick", Toggle)

	local autoAcceptLoot = LibStub("tekKonfig-Checkbox").new(looting, nil, BrokerGarbage_LootManager.locale.LMAutoAcceptLootTitle, "TOPLEFT", forceClear, "BOTTOMLEFT", 0, 4)
	autoAcceptLoot.tiptext =  BrokerGarbage_LootManager.locale.LMAutoAcceptLootTooltip .. BrokerGarbage.locale.GlobalSetting
	autoAcceptLoot.stat = "autoConfirmBoP"
	autoAcceptLoot.global = true
	autoAcceptLoot:SetChecked(BGLM_GlobalDB.autoConfirmBoP)
	autoAcceptLoot:SetScript("OnClick", Toggle)
	
	local notices = LibStub("tekKonfig-Group").new(panel, BrokerGarbage_LootManager.locale.GroupNotices, "TOPLEFT", looting, "TOPRIGHT", 10, 0)
	notices:SetHeight(110); notices:SetWidth(180)
	notices:SetBackdropColor(0.1, 0.1, 0.1, 0.4)

	local openContainers = LibStub("tekKonfig-Checkbox").new(notices, nil, BrokerGarbage_LootManager.locale.LMOpenContainersTitle, "TOPLEFT", 4, -2)
	openContainers.tiptext = BrokerGarbage_LootManager.locale.LMOpenContainersTooltip .. BrokerGarbage.locale.GlobalSetting
	openContainers.stat = "openContainers"
	openContainers.global = true
	openContainers:SetChecked(BGLM_GlobalDB.openContainers)
	openContainers:SetScript("OnClick", Toggle)

	local openClams = LibStub("tekKonfig-Checkbox").new(notices, nil, BrokerGarbage_LootManager.locale.LMOpenClamsTitle, "TOPLEFT", openContainers, "BOTTOMLEFT", 0, 4)
	openClams.tiptext = BrokerGarbage_LootManager.locale.LMOpenClamsTooltip .. BrokerGarbage.locale.GlobalSetting
	openClams.stat = "openClams"
	openClams.global = true
	openClams:SetChecked(BGLM_GlobalDB.openClams)
	openClams:SetScript("OnClick", Toggle)

	-- -----------------------------------------------------------------
	local line2 = CreateHorizontalRule(notices)
	line2:SetPoint("TOPLEFT", openClams, "BOTTOMLEFT", 2, -2)
	line2:SetPoint("RIGHT", -6, 2)
	-- -----------------------------------------------------------------

	local warnLM = LibStub("tekKonfig-Checkbox").new(notices, nil, BrokerGarbage_LootManager.locale.LMWarnLMTitle, "TOPLEFT", openClams, "BOTTOMLEFT", 0, 4-12)
	warnLM.tiptext = BrokerGarbage_LootManager.locale.LMWarnLMTooltip .. BrokerGarbage.locale.GlobalSetting
	warnLM.stat = "warnLM"
	warnLM.global = true
	warnLM:SetChecked(BGLM_GlobalDB.warnLM)
	warnLM:SetScript("OnClick", Toggle)
	
	local inventoryFull = LibStub("tekKonfig-Checkbox").new(notices, nil, BrokerGarbage_LootManager.locale.LMWarnInventoryFullTitle, "TOPLEFT", warnLM, "BOTTOMLEFT", 0, 4)
	inventoryFull.tiptext = BrokerGarbage_LootManager.locale.LMWarnInventoryFullTooltip .. BrokerGarbage.locale.GlobalSetting
	inventoryFull.stat = "warnInvFull"
	inventoryFull.global = true
	inventoryFull:SetChecked(BGLM_GlobalDB.warnInvFull)
	inventoryFull:SetScript("OnClick", Toggle)
	
	local inventory = LibStub("tekKonfig-Group").new(panel, BrokerGarbage_LootManager.locale.GroupInventory, "TOPLEFT", looting, "BOTTOMLEFT", 0, -14)
	inventory:SetHeight(75); inventory:SetWidth(180)
	inventory:SetBackdropColor(0.1, 0.1, 0.1, 0.4)

	local restack = LibStub("tekKonfig-Checkbox").new(inventory, nil, BrokerGarbage_LootManager.locale.LMRestackTitle, "TOPLEFT", 4, -2)
	restack.tiptext = BrokerGarbage_LootManager.locale.LMRestackTooltip .. BrokerGarbage.locale.GlobalSetting
	restack.stat = "restackInventory"
	restack.global = true
	restack:SetChecked(BGLM_GlobalDB.restackInventory)
	restack:SetScript("OnClick", Toggle)

	local autoDestroy = LibStub("tekKonfig-Checkbox").new(inventory, nil, BrokerGarbage_LootManager.locale.LMAutoDestroyTitle, "TOPLEFT", restack, "BOTTOMLEFT", 0, 4)
	autoDestroy.tiptext = BrokerGarbage_LootManager.locale.LMAutoDestroyTooltip
	autoDestroy.stat = "autoDestroy"
	autoDestroy:SetChecked(BGLM_LocalDB.autoDestroy)
	autoDestroy:SetScript("OnClick", Toggle)

	local autoDestroyInstant = LibStub("tekKonfig-Checkbox").new(inventory, nil, BrokerGarbage_LootManager.locale.LMAutoDestroyInstantTitle, "TOPLEFT", autoDestroy, "BOTTOMLEFT", 14, 4)
	autoDestroyInstant.tiptext = BrokerGarbage_LootManager.locale.LMAutoDestroyInstantTooltip
	autoDestroyInstant.stat = "autoDestroyInstant"
	autoDestroyInstant:SetChecked(BGLM_LocalDB.autoDestroyInstant)
	autoDestroyInstant:SetScript("OnClick", Toggle)
	
	local treshold = LibStub("tekKonfig-Group").new(panel, BrokerGarbage_LootManager.locale.GroupTreshold, "TOPLEFT", notices, "BOTTOMLEFT", 0, -14)
	treshold:SetHeight(90); treshold:SetWidth(180)
	treshold:SetBackdropColor(0.1, 0.1, 0.1, 0.4)

	local editbox = CreateFrame("EditBox", nil, treshold)
	editbox:SetPoint("TOPLEFT", 13, -16)
	editbox:SetAutoFocus(false)
	editbox:SetWidth(160); editbox:SetHeight(32)
	editbox:SetFontObject("GameFontHighlightSmall")
	editbox:SetJustifyH("CENTER")
	editbox:SetText(BrokerGarbage:FormatMoney(BGLM_LocalDB.itemMinValue))
	local left = editbox:CreateTexture(nil, "BACKGROUND")
	left:SetWidth(8) left:SetHeight(20)
	left:SetPoint("LEFT", -5, 0)
	left:SetTexture("Interface\\Common\\Common-Input-Border")
	left:SetTexCoord(0, 0.0625, 0, 0.625)
	local right = editbox:CreateTexture(nil, "BACKGROUND")
	right:SetWidth(8) right:SetHeight(20)
	right:SetPoint("RIGHT", 0, 0)
	right:SetTexture("Interface\\Common\\Common-Input-Border")
	right:SetTexCoord(0.9375, 1, 0, 0.625)
	local center = editbox:CreateTexture(nil, "BACKGROUND")
	center:SetHeight(20)
	center:SetPoint("RIGHT", right, "LEFT", 0, 0)
	center:SetPoint("LEFT", left, "RIGHT", 0, 0)
	center:SetTexture("Interface\\Common\\Common-Input-Border")
	center:SetTexCoord(0.0625, 0.9375, 0, 0.625)
	
	local minValueLabel = editbox:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	minValueLabel:SetPoint("BOTTOM", editbox, "TOP", 0, -4)
	minValueLabel:SetText(BrokerGarbage_LootManager.locale.LMItemMinValue)
	
	local function ResetEditBox(self)
		self:SetText(BrokerGarbage:FormatMoney(BGLM_LocalDB.itemMinValue))
		self:ClearFocus()
	end
	local function UnFormatEditBox(self)
		self:SetText(BGLM_LocalDB.itemMinValue)
	end
	local function SubmitEditBox()
		BGLM_LocalDB.itemMinValue = tonumber(editbox:GetText())
		editbox:SetText(BrokerGarbage:FormatMoney(BGLM_LocalDB.itemMinValue))
		editbox:ClearFocus()
	end
	editbox:SetScript("OnEscapePressed", ResetEditBox)
	editbox:SetScript("OnEnterPressed", SubmitEditBox)
	editbox:SetScript("OnEditFocusGained", UnFormatEditBox)

	local minFreeSlots, minFreeSlotsText, _, low, high = LibStub("tekKonfig-Slider").new(treshold, BrokerGarbage_LootManager.locale.LMFreeSlotsTitle .. ": " .. BGLM_GlobalDB.tooFewSlots, 0, 30, "TOPLEFT", editbox, "BOTTOMLEFT", 6, -8)
	minFreeSlots.tiptext = BrokerGarbage_LootManager.locale.LMFreeSlotsTooltip .. BrokerGarbage.locale.GlobalSetting
	minFreeSlots:SetWidth(160)
	minFreeSlots:SetValueStep(1)
	minFreeSlots:SetValue(BGLM_GlobalDB.tooFewSlots)
	minFreeSlots:SetScript("OnValueChanged", function(minFreeSlots)
		BGLM_GlobalDB.tooFewSlots = minFreeSlots:GetValue()
		minFreeSlotsText:SetText(BrokerGarbage_LootManager.locale.LMFreeSlotsTitle .. ": " .. BGLM_GlobalDB.tooFewSlots)
		BrokerGarbage:ScanInventory()
	end)
	low:Hide(); high:Hide()
	
	function panel:Update()
		editbox:SetText(BrokerGarbage:FormatMoney(BGLM_LocalDB.itemMinValue))
		
		local min, max = minFreeSlots:GetMinMaxValues()
		if BGLM_GlobalDB.tooFewSlots > min and BGLM_GlobalDB.tooFewSlots < max then
			minFreeSlots:SetValue(BGLM_GlobalDB.tooFewSlots)
		end
		minFreeSlotsText:SetText(BrokerGarbage_LootManager.locale.LMFreeSlotsTitle .. ": " .. BGLM_GlobalDB.tooFewSlots)
	end
end
BrokerGarbage_LootManager.options = panel

local _ = BrokerGarbage:RegisterPlugin(BrokerGarbage_LootManager.locale.LMTitle, Options_LootManager)